app.directive('photoPickable', function() {
  return {
    restrict: 'AE',
    scope: {
      number: '@',
      id: '@',
      imgSrc: '=',
    },
    template: '' +
      '<div class="photo-pickable" ng-click="showActionSheet()">' +
      '<span class="photo-number text-lg light">{{number}}</span>' +
      '<img ng-src="{{imgSrc}}" class="w-full r-3x" alt="">' +
      '<i class="icon ion-close-round photo-button assertive light-bg text-2x rounded"></i>' +
      '<i class="icon ion-plus-circled photo-button assertive light-bg text-2x rounded"></i>' +
      '</div>',
    controller: function($scope, $rootScope, $cordovaCamera, $ionicActionSheet, $state) {
      //$scope.imgSrc = 'img/ben.png';
      var hideSheet;
      var actionBtns = [{
        text: '<i class="icon androidOnly ion-person"></i> Set As Cover Image',
        Action: function() {
          _setCoverImage();
        }
      },{
        text: '<i class="icon androidOnly ion-camera"></i> Camera',
        Action: function() {
          try{
            $scope.pick(Camera.PictureSourceType.CAMERA);          
          }catch(err){
            _testImageData();
            toastr.error('Camera not available')
          }
          hideSheet();
        }
      }, {
        text: '<i class="icon androidOnly ion-images"></i> Gallery',
        Action: function() {
          try{
            $scope.pick(Camera.PictureSourceType.PHOTOLIBRARY);
          }catch(err){
            _testImageData();
            toastr.error('Gallery not available')
          }
          hideSheet();
        }
      }, {
        text: '<i class="icon androidOnly ion-social-facebook"></i> Facebook',
        Action: function() {
          $state.go('home.fbImages');
          hideSheet();
        }
      }];

      $scope.showActionSheet = function() {
        hideSheet = $ionicActionSheet.show({
          buttons: actionBtns,
          destructiveText: '<i class="icon androidOnly ion-ios-trash"></i> Delete',
          titleText: 'Modify your album',
          cancelText: '<i class="icon androidOnly ion-ios-arrow-down"></i> Cancel',
          cancel: function() {
            // add cancel code..
          },
          buttonClicked: function(index) {
            actionBtns[index].Action();
          },
          destructiveButtonClicked: function() {
            if($scope.id == 0){
              hideSheet();
              return;
            }
            $scope.$parent.ajaxGetPromise('ProfileImageApi/delete/'+ $scope.id, null)
              .then(function(response){
                hideSheet();
                if(!response.Success) return;
                $scope.imgSrc = $scope.$parent.GenerateImageUrl('', true);
                $scope.id = 0;
              })
          }
        });
      }

      var _testImageData = function(){
        $.get('ImageData.txt',function(data){
          _uploadImage(data)
        });
      }

      $scope.pick = function(sourceType) {
        if (Camera === undefined) {
          toastr.error('Camera not available')
          return false;
        }
        var options = {
          quality         : 50, 
          destinationType : Camera.DestinationType.DATA_URL,
          targetWidth     : 400,
          targetHeight    : 300,
          sourceType      : sourceType,
          allowEdit       : true,
        };

        $cordovaCamera.getPicture(options)
          .then(_uploadImage, function(err) {
            toastr.error('Could\'nt upload image, try again')
          });
      }
      var _setCoverImage = function(){
        if($scope.id == 0){
          toastr.info('Can not set empty image as Cover');
          hideSheet();
          return;
        }
        var request = {
            Id              : $scope.id,
            Caption         : 'tempFile',
            IsCover         : true,
            SecurityLevel   : 1
        }

        $scope.$parent.ajaxPostPromise('ProfileImageApi/Edit', request)
          .then(function(response){
            if(!response.Success)
              return;
            
            $scope.$parent.CurrentUser.ShortDetails.CoverImage = $scope.imgSrc.replace('_164x164.jpg','');
            var temp = angular.copy($scope.$parent.ProfileImgs[0]);
            $scope.$parent.ProfileImgs[0] = angular.copy($scope.$parent.ProfileImgs[$scope.number - 1]);
            $scope.$parent.ProfileImgs[$scope.number - 1]  = temp;
            hideSheet();
          }) 
      }

      var _uploadImage = function(imageData){
        //$scope.imgSrc = imageData;
        var data  = {
          Base64_encodedString  : imageData,
          FileName        : 'tempFile',
          IsCover         : $scope.number == 1,
          SecurityLevel   : 1,
          Source          : 'FromMobile'
        }

        $scope.$parent.ajaxPostPromise('ProfileImageApi/Save', data)
          .then(function(response){
            if(!response.Success)
              return;
            $scope.$parent.imageUploadedForApproval = true;
            hideSheet();
            //toastr.success('Your image has been submitted for approval')
          }) 
      }
    }
  }
})
