app.factory('facebookApiService', function() {
    return {
        isMobile: (document.URL.indexOf('http') === -1),
        api: function(requestPath, permissions, success, failure) {
            if (this.isMobile) {
                facebookConnectPlugin.api(requestPath, permissions, success, failure);
            } else {
                facebookConnectPlugin.api(requestPath, success)
            }
        },
        login: function(permissionString, success, failure, auth_type) {
            if (this.isMobile) {
                facebookConnectPlugin.login(permissionString.split(','), success, failure)
            } else {
                var obj = {
                    scope: permissionString
                };
                if (auth_type) {
                    obj.auth_type = auth_type;
                }
                facebookConnectPlugin.login(success, obj);
            }
        },
        IsUserLoggedIn: function(success, failure) {
            facebookConnectPlugin.getLoginStatus(function(response) {
                success(response.status === 'connected')
            }, failure);
        },
        logout: function(success, failure) {
            if (this.isMobile) {
                facebookConnectPlugin.logout(success, failure)
            } else {
                facebookConnectPlugin.logout(success)
            }
        },
        hasPhotoPermission: function(callback) {
            this.api('/me/permissions', [], function(response) {
                response.data.forEach(function(item) {
                    if (item.permission == 'user_photos' && item.status == 'declined') {
                        callback(false);
                    } else if (item.permission == 'user_photos' && item.status == 'granted') {
                        callback(true);
                    }
                })
            }, function(e) {
                alert('Facebook: Failed to get permissions');
            });
        },
        getProfileAlbum: function(callback) {
            var self = this;
            self.api('/me/albums', ['public_profile'], function(response) {
                if (!response || response.error) {
                    callback(false);
                    return
                }
                if (response.data.length == 0) {
                    callback(false);
                    return
                }
                var imageUrl = [];
                for (key in response.data) {
                    if (response.data[key].name === "Profile Pictures") {
                        self.api("/" + response.data[key].id + "/photos?fields=images,picture,source", ['user_photos'], function(responsePhoto) {
                            for (photoIndex in responsePhoto.data) {
                                var thumImg = responsePhoto.data[photoIndex].picture
                                var orgImg = responsePhoto.data[photoIndex].source
                                imageUrl.push({
                                    ThumbnailUrl: thumImg,
                                    OrignalImage: orgImg,
                                    Selected: false
                                });
                            }
                            callback(true, imageUrl)
                        }, function(e) {
                            console.log("Failed: " + e)
                        })
                    }
                }
            })
        },
        fetchPublicProfile: function(callback) {
            var self = this;
            self.IsUserLoggedIn(function(loggedIn){
                if(loggedIn){
                    self.api('/me?fields=email,id', ['public_profile'], function(data) {
                        callback(true, data)
                    }, function(e) {
                        callback(false)
                    })                    
                }else{
                    self.login('public_profile,email', function(res){
                        if(res.status === 'connected')
                            self.fetchPublicProfile(callback);
                        else
                            callback(false)
                    },function(){
                        callback(false)
                    })
                }
            })
        },
        //returns data upon success and false upon failure
        fetchUserDetails : function(callback){
            var self = this;
            var permissionString = 'email,user_birthday,user_location,user_relationships,user_religion_politics,user_photos';
            self.login(permissionString, function(response){
                if (response.authResponse) {
                    self.IsUserLoggedIn(function(isLoggedIn){
                        if(isLoggedIn){         
                            self.api('/me?fields=first_name,last_name,gender,location,email,birthday,id,relationship_status',permissionString.split(','), function(dataResponse){
                                callback(self.extractData(dataResponse));
                            }, function(e){ callback(false); })
                        }
                    },function(err){ callback(false) })
                } else {
                  callback(false);
                }
            }, function(err){
                callback(false);
            })
        },
        extractData : function(response){
            try{
            var data = {};
            data.FirstName = response.first_name + " " + ((typeof response.middle_name != 'undefined') ? response.middle_name : "")

            data.LastName = response.last_name

            data.Gender = response.gender[0].toUpperCase();

            if (response.birthday) {
                data.DobMonth = parseInt(response.birthday.split('/')[0])
                data.DobYear = parseInt(response.birthday.split('/')[2])
                data.DobDay = parseInt(response.birthday.split('/')[1])      
            } else {
                console.log('birthday not returned')
            }
                    
            data.Email = response.email;
            data.FacebookId = response.id
            data.Username = response.email.split('@')[0];
            data.FacebookEmail = response.email

            var maritalStatus;
            switch (response.relationship_status) {
                case "Single": maritalStatus = 1;
                    break;
                case "Married": maritalStatus = 2;
                    break
                case "Widowed": maritalStatus = 3;
                    break;
                case "Divorced": maritalStatus = 4;
                    break;
                case "Separated": maritalStatus = 5;
                    break;
            }        

            if (maritalStatus) {
                data.MaritalStatusId = maritalStatus
            }
            else {          
                data.MaritalStatusId = 1;//never married by default
                console.log('MaritalStatus not returned')
            }
            //Just Sunni Muslim by default
            data.DenominationId = 8;

            if (response.location) {
                var isFound = false;
                var lookupdata = JSON.parse(localStorage['LookupData']);
                angular.forEach(lookupdata.CountriesWithCode, function(c){
                    if (c.Description == (response.location.name.split(', ')[1])) {
                        data.CountryAbbreviation = c.Value;
                    }                     
                })
            } else {
                console.log('location not returned')
            }
            return data;   
            }catch(err){
                alert(err.message)
            }
        }
    }
})